@@ -37,6 +37,17 @@ public:
 typedef std::list<Currency> type_list_currencies;
 type_list_currencies get_list_of_currency_symbols();
 
+class Locale
+{
+public:
+  Glib::ustring m_identifier;
+  Glib::ustring m_name;
+};
+
+typedef std::list<Locale> type_list_locales;
+type_list_locales get_list_of_locales();
+
+Glib::ustring get_locale_name(const Glib::ustring& locale_id);
 }
 
 #endif //GLOM_DATASTRUCTURE_ISO_CODES_H
