@@ -28,7 +28,7 @@ class CalcInProgress
 public:
   CalcInProgress();
 
-  Field m_field;
+  sharedptr<const Field> m_field;
   Gnome::Gda::Value m_value; //If it's been calculated.
   bool m_calc_in_progress;
   bool m_calc_finished;
