@@ -136,7 +136,7 @@ void Dialog_UsersList::set_document(const Glib::ustring& layout, Document_Glom*
     //guint group_sequence = 1; //0 means no sequence
     for(Document_Glom::type_mapLayoutGroupSequence::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
     {
-      const LayoutGroup& group = iter->second;
+      sharedptr<const LayoutGroup> group = iter->second;
 
       add_group(Gtk::TreeModel::iterator(), group);
     }
@@ -154,6 +154,9 @@ void Dialog_UsersList::set_document(const Glib::ustring& layout, Document_Glom*
 
 void Dialog_UsersList::enable_buttons()
 {
+  if(!m_button_user_edit)
+   return;
+
   //Fields:
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_users->get_selection();
   if(refSelection)
@@ -189,8 +192,8 @@ void Dialog_UsersList::on_button_user_remove()
         const Glib::ustring user = row[m_model_columns_users.m_col_name];
         if(!user.empty())
         {
-          Glib::ustring strQuery = "ALTER GROUP " + m_combo_group->get_active_text() + " DROP USER " + user;
-          Query_execute(strQuery);
+          Glib::ustring strQuery = "ALTER GROUP \"" + m_combo_group->get_active_text() + "\" DROP USER \"" + user + "\"";
+          Query_execute(strQuery, this);
 
           fill_list();
         }
@@ -227,7 +230,7 @@ void Dialog_UsersList::on_button_user_delete()
           if(response == Gtk::RESPONSE_OK)
           {
             Glib::ustring strQuery = "DROP USER " + user;
-            Query_execute(strQuery);
+            Query_execute(strQuery, this);
 
             fill_list();
           }
@@ -270,16 +273,16 @@ void Dialog_UsersList::on_button_user_add()
   if(!user.empty())
   {
     //Add it to the group:
-    Glib::ustring strQuery = "ALTER GROUP " + m_combo_group->get_active_text() + " ADD USER " + user;
-    Query_execute(strQuery);
+    Glib::ustring strQuery = "ALTER GROUP \"" + m_combo_group->get_active_text() + "\" ADD USER " + user;
+    Query_execute(strQuery, this);
 
     //Remove any user rights, so that all rights come from the user's presence in the group:
     Document_Glom::type_listTableInfo table_list = get_document()->get_tables();
 
     for(Document_Glom::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
     {
-      Glib::ustring strQuery = "REVOKE ALL PRIVILEGES ON " + iter->get_name() + " FROM " + user;
-      Query_execute(strQuery);
+      Glib::ustring strQuery = "REVOKE ALL PRIVILEGES ON \"" + (*iter)->get_name() + "\" FROM \"" + user + "\"";
+      Query_execute(strQuery, this);
     }
 
     fill_list();
@@ -314,12 +317,12 @@ void Dialog_UsersList::on_button_user_new()
   if(!user.empty() && !password.empty())
   {
     //Create the user:
-    Glib::ustring strQuery = "CREATE USER " + user + " PASSWORD '" + password + "'" ;
-    Glib::RefPtr<Gnome::Gda::DataModel> data_model = Query_execute(strQuery);
+    Glib::ustring strQuery = "CREATE USER \"" + user + "\" PASSWORD '" + password + "'" ;
+    Glib::RefPtr<Gnome::Gda::DataModel> data_model = Query_execute(strQuery, this);
 
     //Add it to the group:
-    strQuery = "ALTER GROUP " + m_combo_group->get_active_text() + " ADD USER " + user;
-    data_model = Query_execute(strQuery);
+    strQuery = "ALTER GROUP \"" + m_combo_group->get_active_text() + "\" ADD USER \"" + user + "\"";
+    data_model = Query_execute(strQuery, this);
 
     fill_list();
   }
@@ -379,8 +382,8 @@ void Dialog_UsersList::on_button_user_edit()
 
       if(!user.empty() && !password.empty())
       {
-        Glib::ustring strQuery = "ALTER USER " + user + " PASSWORD '" + password + "'" ;
-        Glib::RefPtr<Gnome::Gda::DataModel> data_model = Query_execute(strQuery);
+        Glib::ustring strQuery = "ALTER USER \"" + user + "\" PASSWORD '" + password + "'" ;
+        Glib::RefPtr<Gnome::Gda::DataModel> data_model = Query_execute(strQuery, this);
 
         //Change the password in the current connection, if this is the current user.
          ConnectionPool* connection_pool = ConnectionPool::get_instance();
