@@ -24,6 +24,7 @@
 #include <gtkmm.h>
 #include "../data_structure/field.h"
 #include "layoutwidgetfield.h"
+#include <libglademm.h>
 
 class App_Glom;
 
@@ -33,41 +34,56 @@ class ImageGlom
 {
 public:
   ImageGlom();
+  explicit ImageGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+
 
   virtual ~ImageGlom();
-  
+
   virtual void set_value(const Gnome::Gda::Value& value);
   virtual Gnome::Gda::Value get_value() const;
   virtual bool get_has_original_data() const;
 
+  //Optionally use this instead of set_value(), to avoid creating an unncessary Value.
+  void set_pixbuf(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf);
+
+  void do_choose_image();
+
+  void set_read_only(bool read_only = true);
+
 protected:
+  void init();
+
+
+  virtual bool on_expose_event(GdkEventExpose* event);
 
   virtual bool on_button_press_event(GdkEventButton *event);
   void on_menupopup_activate_select_file();
   void on_menupopup_activate_copy();
   void on_menupopup_activate_paste();
   void on_menupopup_activate_clear();
-  
+
   void on_clipboard_get(Gtk::SelectionData& selection_data, guint /* info */);
   void on_clipboard_clear();
   void on_clipboard_received_image(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf);
 
   virtual App_Glom* get_application();
-  
+
   void setup_menu_usermode();
   void scale();
-  
+
   static Glib::RefPtr<Gdk::Pixbuf> scale_keeping_ratio(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf, int target_height, int target_width);
-  
+
   Gtk::Image m_image;
   Gtk::Frame m_frame;
   Glib::RefPtr<Gdk::Pixbuf> m_pixbuf_original; //Only stored temporarily, because it could be big.
   Glib::RefPtr<Gdk::Pixbuf> m_pixbuf_clipboard; //When copy is used, store it here until it is pasted.
-  
+
   Gtk::Menu* m_pMenuPopup_UserMode;
   Glib::RefPtr<Gtk::ActionGroup> m_refActionGroup_UserModePopup;
   Glib::RefPtr<Gtk::UIManager> m_refUIManager_UserModePopup;
   Glib::RefPtr<Gtk::Action> m_refActionSelectFile, m_refActionCopy, m_refActionPaste, m_refActionClear;
+
+  bool m_read_only;
 };
 
 #endif //GLOM_UTILITY_WIDGETS_COMBOENTRY_GLOM_H
