@@ -22,12 +22,18 @@
 #include "connectionpool.h"
 #include "data_structure/layout/report_parts/layoutitem_fieldsummary.h"
 #include "data_structure/glomconversions.h"
+#include "frame_glom.h"
 #include <libxml++/libxml++.h>
 #include <libxslt/transform.h>
+//#include <libexslt/exslt.h> //For exsltRegisterAll().
 #include <libgnomevfsmm.h>
+#include <glibmm/i18n.h>
 #include <libgnome/gnome-url.h>
 #include <sstream> //For stringstream
 
+#include <iostream>
+#include <fstream>
+
 #include <locale>     // for locale, time_put
 #include <ctime>     // for struct tm
 #include <iostream>   // for cout, endl
@@ -167,18 +173,56 @@ Glib::ustring GlomUtils::string_replace(const Glib::ustring& src, const Glib::us
 
 
 
-Glib::ustring GlomUtils::build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Glib::ustring& where_clause, const Glib::ustring& sort_clause)
+Glib::ustring GlomUtils::build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Glib::ustring& where_clause, const type_sort_clause& sort_clause)
 {
   Glib::ustring result;
 
+  //Get all relationships used in the query:
+  typedef std::list< sharedptr<const UsesRelationship> > type_list_relationships;
+  type_list_relationships list_relationships;
+
+  for(type_vecLayoutFields::const_iterator iter = fieldsToGet.begin(); iter != fieldsToGet.end(); ++iter)
+  {
+    sharedptr<LayoutItem_Field> layout_item = *iter;
+
+    if(layout_item->get_has_relationship_name())
+    {
+      //Add the relationship to the list:
+      type_list_relationships::const_iterator iterFind = std::find_if(list_relationships.begin(), list_relationships.end(), predicate_UsesRelationshipHasRelationships<UsesRelationship>(layout_item) );
+      if(iterFind == list_relationships.end()) //If the table is not yet in the list:
+      {
+        sharedptr<UsesRelationship> uses_rel = sharedptr<UsesRelationship>::create();
+        uses_rel->set_relationship(layout_item->get_relationship());
+        uses_rel->set_related_relationship(layout_item->get_related_relationship());
+        list_relationships.push_back(uses_rel);
+      }
+    }
+  }
+
+  for(type_sort_clause::const_iterator iter = sort_clause.begin(); iter != sort_clause.end(); ++iter)
+  {
+    sharedptr<const LayoutItem_Field> layout_item = iter->first;
+
+    if(layout_item->get_has_relationship_name())
+    {
+      //Add the relationship to the list:
+      type_list_relationships::const_iterator iterFind = std::find_if(list_relationships.begin(), list_relationships.end(), predicate_UsesRelationshipHasRelationships<UsesRelationship>(layout_item) );
+      if(iterFind == list_relationships.end()) //If the table is not yet in the list:
+      {
+        sharedptr<UsesRelationship> uses_rel = sharedptr<UsesRelationship>::create();
+        uses_rel->set_relationship(layout_item->get_relationship());
+        uses_rel->set_related_relationship(layout_item->get_related_relationship());
+        list_relationships.push_back(uses_rel);
+      }
+    }
+  }
+
+
+
   Glib::ustring sql_part_fields;
   Glib::ustring sql_part_from;
 
-  typedef std::list< sharedptr<const UsesRelationship> > type_list_relationships;
-  type_list_relationships list_relationships;
-
-
-  for(type_vecLayoutFields::const_iterator iter =  fieldsToGet.begin(); iter != fieldsToGet.end(); ++iter)
+  for(type_vecLayoutFields::const_iterator iter = fieldsToGet.begin(); iter != fieldsToGet.end(); ++iter)
   {
     Glib::ustring one_sql_part;
 
@@ -194,18 +238,6 @@ Glib::ustring GlomUtils::build_sql_select_with_where_clause(const Glib::ustring&
       one_sql_part += fieldsummary->get_summary_type_sql() + "(";
 
     one_sql_part += ( "\"" + layout_item->get_sql_table_or_join_alias_name(table_name) + "\"." );
-    if(layout_item->get_has_relationship_name())
-    {
-      //Add the relationship to the list:
-      type_list_relationships::const_iterator iterFind = std::find_if(list_relationships.begin(), list_relationships.end(), predicate_UsesRelationshipHasRelationships<UsesRelationship>(layout_item) );
-      if(iterFind == list_relationships.end()) //If the table is not yet in the list:
-      {
-        sharedptr<UsesRelationship> uses_rel = sharedptr<UsesRelationship>::create();
-        uses_rel->set_relationship(layout_item->get_relationship());
-        uses_rel->set_related_relationship(layout_item->get_related_relationship());
-        list_relationships.push_back(uses_rel);
-      }
-    }
 
     const Glib::ustring name = layout_item->get_name();
     if(!name.empty())
@@ -268,8 +300,27 @@ Glib::ustring GlomUtils::build_sql_select_with_where_clause(const Glib::ustring&
   if(!where_clause.empty())
     result += " WHERE " + where_clause;
 
+  //Sort clause:
   if(!sort_clause.empty())
-    result += " " + sort_clause;
+  {
+    Glib::ustring str_sort_clause;
+    for(type_sort_clause::const_iterator iter = sort_clause.begin(); iter != sort_clause.end(); ++iter)
+    {
+      sharedptr<const LayoutItem_Field> layout_item = iter->first;
+      if(layout_item)
+      {
+        const bool ascending = iter->second;
+
+        if(!str_sort_clause.empty())
+          str_sort_clause += ", ";
+
+        str_sort_clause += "\"" + layout_item->get_sql_table_or_join_alias_name(table_name) + "\".\"" + layout_item->get_name() + "\" " + (ascending ? "ASC" : "DESC");
+      }
+    }
+
+    if(!str_sort_clause.empty())
+      result += " ORDER BY " + str_sort_clause;
+  }
 
   return result;
 }
@@ -343,7 +394,7 @@ GlomUtils::type_list_values_with_second GlomUtils::get_choice_values(const share
 }
 
 
-void GlomUtils::transform_and_open(const xmlpp::Document& xml_document, const Glib::ustring& xsl_file_path)
+void GlomUtils::transform_and_open(const xmlpp::Document& xml_document, const Glib::ustring& xsl_file_path, Gtk::Window* parent_window)
 {
   //Use libxslt to convert the XML to HTML:
   Glib::ustring result = xslt_process(xml_document, GLOM_XSLTDIR + xsl_file_path);
@@ -379,6 +430,10 @@ void GlomUtils::transform_and_open(const xmlpp::Document& xml_document, const Gl
     return; //print_error(ex, output_uri_string);
   }
 
+  //Give the user a clue, in case the web browser opens in the background, for instance in a new tab:
+  if(parent_window)
+    Frame_Glom::show_ok_dialog(_("Report Finished"), _("The report will now be opened in your web browser."), *parent_window, Gtk::MESSAGE_INFO);
+
   //Use the GNOME browser:
   GError* error = 0;
   gnome_url_show(temp_uri.c_str(), &error); //This is in libgnome.
@@ -387,7 +442,7 @@ void GlomUtils::transform_and_open(const xmlpp::Document& xml_document, const Gl
 Glib::ustring GlomUtils::create_name_from_title(const Glib::ustring& title)
 {
   Glib::ustring result = string_replace(title, " ", "");
-  return result.lowercase(); //Database titles must be lowercase, it seems. TODO: Maybe they need to be ASCII (not UTF8)?
+  return result.lowercase(); //TODO: Maybe they need to be ASCII (not UTF8)?
 }
 
 Glib::ustring GlomUtils::xslt_process(const xmlpp::Document& xml_document, const std::string& filepath_xslt)
@@ -405,6 +460,10 @@ Glib::ustring GlomUtils::xslt_process(const xmlpp::Document& xml_document, const
   xmlDocPtr style = xmlReadFile(filepath_xslt.c_str(), 0, 0);
   if(style)
   {
+    //We need this to be able to use the exsl: functions, even if we declare the namespace at the start of the xsl.
+    //We don't need this anymore - we use xsl:copy-of instead of exsl:node-set (which didn't work as expected anyway):
+    //exsltRegisterAll();
+
     //Parse the stylesheet:
     xsltStylesheetPtr cur = xsltParseStylesheetDoc(style);
     if(cur)
@@ -489,3 +548,50 @@ Glib::ustring GlomUtils::locale_language_id(const Glib::ustring& locale_id)
 
   return result;
 }
+
+Glib::ustring GlomUtils::create_local_image_uri(const Gnome::Gda::Value& value)
+{
+  static guint m_temp_image_uri_number = 0;
+
+  Glib::ustring result;
+
+  if(value.get_value_type() == Gnome::Gda::VALUE_TYPE_BINARY)
+  {
+    glong size = 0;
+    const gpointer pData = value.get_binary(size);
+    if(size && pData)
+    {
+      //libgda does not currently properly unescape binary data,
+      //so pData is actually a null terminated string, of escaped binary data.
+      //This workaround should be removed when libgda is fixed:
+      //(It is fixed in libgd-2.0 but is unlikely to be fixed in libgda-1.2)
+      size_t buffer_binary_length = 0;
+      guchar* buffer_binary =  Glom_PQunescapeBytea((const guchar*)pData /* must be null-terminated */, &buffer_binary_length); //freed by us later.
+      if(buffer_binary)
+      {
+        //Saves the image to a temporary file and provides the file URI.
+        char pchExtraNum[10];
+        sprintf(pchExtraNum, "%d", m_temp_image_uri_number);
+        result = ("/tmp/glom_report_image_" + Glib::ustring(pchExtraNum) + ".png");
+        ++m_temp_image_uri_number;
+
+        std::fstream the_stream(result.c_str(), std::ios_base::out | std::ios_base::trunc | std::ios_base::binary);
+        if(the_stream)
+        {
+          the_stream.write((char*)buffer_binary, buffer_binary_length);
+        }
+
+        free(buffer_binary);
+      }
+    }
+    else
+       std::cerr << "GlomUtils::create_local_image_uri(): binary GdaValue contains no data." << std::endl;
+  }
+  //else
+  //  std::cerr << "GlomUtils::create_local_image_uri(): type != BINARY" << std::endl;
+
+  if(result.empty())
+    result = "/tmp/glom_report_image_invalid.png";
+
+  return ("file://" + result);
+}
